package com.vazil.vridge.docs.controller;

import com.vazil.vridge.docs.model.Guide;
import com.vazil.vridge.docs.model.GuideContent;
import com.vazil.vridge.docs.model.GuideTest;
import com.vazil.vridge.docs.service.GuideService;
import com.vazil.vridge.docs.service.GuideTestService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import lombok.extern.log4j.Log4j2;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

@RestController
@AllArgsConstructor
@Log4j2
@RequestMapping("/test")
@CrossOrigin
@Api("가이드 API V1")
public class GuideTestController {
    GuideService guideService;
    GuideTestService guideTestService;

    @ApiOperation(value="모든 가이드 목차 조회")
    @GetMapping("/index")
    public ResponseEntity<?> findIndex()throws Exception{
        return new ResponseEntity<>(guideTestService.findGuideIndex(), HttpStatus.OK);

    }

    @ApiOperation(value="모든 가이드 목차 검색")
    @GetMapping("/search")
    public ResponseEntity<?> search(@RequestParam(value = "keyword", required = false) String keyword) throws Exception{
        return new ResponseEntity<>(guideService.search(keyword), HttpStatus.OK);

    }

    @ApiOperation(value="가이드 타이틀 추가")
    @PostMapping
    public ResponseEntity<?> createGuideIndex(@RequestBody GuideTest guide) throws Exception{
        return new ResponseEntity<>(guideTestService.createGuide(guide), HttpStatus.CREATED);

    }

    @PutMapping("/index")
    public ResponseEntity<?> updateGuideIndex(@RequestBody Guide guide) throws Exception{
        return new ResponseEntity<>(guideService.updateGuide(guide), HttpStatus.OK);

    }

    @PutMapping("/keyword")
    public ResponseEntity<?> updateGuideKeyword(@RequestBody Guide guide) throws Exception{
        return new ResponseEntity<>(guideService.updateGuideKeyword(guide), HttpStatus.OK);

    }

    @GetMapping
    public ResponseEntity<?> getGuide(@RequestParam(value = "guideId") String guideId) throws Exception{
        return new ResponseEntity<>(guideTestService.findGuideById(guideId), HttpStatus.OK);

    }

    @DeleteMapping
    public ResponseEntity<?> deleteGuideIndex(@RequestParam(value = "guideId") String guideId, @RequestParam(value = "cascade", required = false) boolean cascade) throws Exception{
        return new ResponseEntity<>(guideService.deleteGuide(guideId, cascade), HttpStatus.OK);

    }

    @PutMapping
    public ResponseEntity<?> updateGuideContent(@RequestBody GuideContent guideContent) throws Exception{
        return new ResponseEntity<>(guideService.updateGuideContent(guideContent), HttpStatus.OK);
    }
}
